@@ -51,11 +51,19 @@ def convert_to_xlsx(
 
 
 def write_workbook(
-    output_path: str, sheets: List[dict], vat_validation=None, validation: bool = False,
+    output_path: str,
+    sheets: List[dict],
+    vat_validation=None,
+    validation: bool = False,
+    progress_reporter: object = None,
 ):
     # Init workbook/sheets
     workbook = xlsxwriter.Workbook(output_path)
 
+    # Add progress counter
+    if progress_reporter:
+        progress_reporter.max += sum([len(*sheet.values()) for sheet in sheets])
+
     # Styling
     header = workbook.add_format({"bold": True})
     probability_format = [
@@ -71,6 +79,7 @@ def write_workbook(
             header,
             probability_format,
             validation,
+            progress_reporter,
         )
 
     if vat_validation:
@@ -80,7 +89,12 @@ def write_workbook(
 
 
 def write_sheet(
-    worksheet, records: list, bold_header, red_to_green_formats: list, validation: bool,
+    worksheet,
+    records: list,
+    bold_header,
+    red_to_green_formats: list,
+    validation: bool,
+    progress_reporter: object = None,
 ):
     """Write items to workbook sheet.
 
@@ -119,6 +133,9 @@ def write_sheet(
 
             count += 1
 
+        if progress_reporter:
+            progress_reporter.current += 1
+
     for i, width in enumerate(get_col_widths(pd.DataFrame.from_records(records))):
         worksheet.set_column(i, i, width)
 
